=========
Changelog
=========

Version 0.2
===========
- Added docs with jupyter-book
- Fixed bug stopping multiple instanced of a JupyXML from working in the same notebook.
  Each instance now has a unique identifier.

Version 0.1
===========

- Added README.md
- Added basic HTML version
- Added Basic Usage example
- Added one test - importing
